summaryrefslogtreecommitdiffstats
path: root/tools/lib/h5tools_utils.c
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>2010-08-24 21:03:32 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>2010-08-24 21:03:32 (GMT)
commit0cd7123fb6ef25fe2be44e53e16b6214c32fb3b9 (patch)
tree26793fd552f75dd0cc6646b7ed8d366d00376c47 /tools/lib/h5tools_utils.c
parent9fbdf8f07aeb41e04108e369196c426b7403881a (diff)
downloadhdf5-0cd7123fb6ef25fe2be44e53e16b6214c32fb3b9.zip
hdf5-0cd7123fb6ef25fe2be44e53e16b6214c32fb3b9.tar.gz
hdf5-0cd7123fb6ef25fe2be44e53e16b6214c32fb3b9.tar.bz2
[svn-r19292] Description:
Merge r19290 & r19291 from 1.8 branch to trunk: r19290: Correct another error in metadata accumulator dirty region calculations (this time with a corner case when freeing data in the file). r19291: Avoid getting object information for soft/external links if we aren't going to traverse across the link itself. Tested on: FreeBSD/32 6.3 (duty) in debug mode FreeBSD/64 6.3 (liberty) w/C++ & FORTRAN, in debug mode Linux/32 2.6 (jam) w/PGI compilers, w/default API=1.8.x, w/C++ & FORTRAN, w/threadsafe, in debug mode Linux/64-amd64 2.6 (amani) w/Intel compilers, w/default API=1.6.x, w/C++ & FORTRAN, in production mode Solaris/32 2.10 (linew) w/deprecated symbols disabled, w/C++ & FORTRAN, w/szip filter, w/threadsafe, in production mode Linux/PPC 2.6 (heiwa) w/C++ & FORTRAN, w/threadsafe, in debug mode Linux/64-ia64 2.6 (cobalt) w/Intel compilers, w/C++ & FORTRAN, in production mode Linux/64-amd64 2.6 (abe) w/parallel, w/FORTRAN, in debug mode Mac OS X/32 10.6.4 (amazon) in debug mode Mac OS X/32 10.6.4 (amazon) w/C++ & FORTRAN, w/threadsafe, in production mode Mac OS X/32 10.6.4 (amazon) w/parallel, in debug mode
Diffstat (limited to 'tools/lib/h5tools_utils.c')
-rw-r--r--tools/lib/h5tools_utils.c68
1 files changed, 37 insertions, 31 deletions
diff --git a/tools/lib/h5tools_utils.c b/tools/lib/h5tools_utils.c
index 2e3c756..a0fca8b 100644
--- a/tools/lib/h5tools_utils.c
+++ b/tools/lib/h5tools_utils.c
@@ -726,7 +726,8 @@ tmpfile(void)
* Date: Feb 8, 2010
*-------------------------------------------------------------------------*/
int
-H5tools_get_link_info(hid_t file_id, const char * linkpath, h5tool_link_info_t *link_info)
+H5tools_get_link_info(hid_t file_id, const char * linkpath, h5tool_link_info_t *link_info,
+ hbool_t get_obj_type)
{
htri_t l_ret;
H5O_info_t trg_oinfo;
@@ -779,37 +780,42 @@ H5tools_get_link_info(hid_t file_id, const char * linkpath, h5tool_link_info_t *
H5Pset_elink_fapl(lapl, fapl);
} /* end if */
- /*--------------------------------------------------------------
- * if link's target object exist, get type
- */
- /* check if target object exist */
- l_ret = H5Oexists_by_name(file_id, linkpath, lapl);
-
- /* detect dangling link */
- if(l_ret == FALSE) {
- ret = 0;
- goto out;
- } /* end if */
- /* function failed */
- else if(l_ret < 0)
- goto out;
-
- /* get target object info */
- if(H5Oget_info_by_name(file_id, linkpath, &trg_oinfo, lapl) < 0) {
- if(link_info->opt.msg_mode == 1)
- parallel_print("Warning: unable to get object information for <%s>\n", linkpath);
- goto out;
+ /* Check for retrieving object info */
+ if(get_obj_type) {
+ /*--------------------------------------------------------------
+ * if link's target object exist, get type
+ */
+ /* check if target object exist */
+ l_ret = H5Oexists_by_name(file_id, linkpath, lapl);
+
+ /* detect dangling link */
+ if(l_ret == FALSE) {
+ ret = 0;
+ goto out;
+ } /* end if */
+ /* function failed */
+ else if(l_ret < 0)
+ goto out;
+
+ /* get target object info */
+ if(H5Oget_info_by_name(file_id, linkpath, &trg_oinfo, lapl) < 0) {
+ if(link_info->opt.msg_mode == 1)
+ parallel_print("Warning: unable to get object information for <%s>\n", linkpath);
+ goto out;
+ } /* end if */
+
+ /* check unknown type */
+ if(trg_oinfo.type < H5O_TYPE_GROUP || trg_oinfo.type >=H5O_TYPE_NTYPES) {
+ if(link_info->opt.msg_mode == 1)
+ parallel_print("Warning: target object of <%s> is unknown type\n", linkpath);
+ goto out;
+ } /* end if */
+
+ /* set target obj type to return */
+ link_info->trg_type = trg_oinfo.type;
} /* end if */
-
- /* check unknown type */
- if(trg_oinfo.type < H5O_TYPE_GROUP || trg_oinfo.type >=H5O_TYPE_NTYPES) {
- if(link_info->opt.msg_mode == 1)
- parallel_print("Warning: target object of <%s> is unknown type\n", linkpath);
- goto out;
- } /* end if */
-
- /* set target obj type to return */
- link_info->trg_type = trg_oinfo.type;
+ else
+ link_info->trg_type = H5O_TYPE_UNKNOWN;
/* succeed */
ret = 1;